@@ -1,12 +1,13 @@
 from pydantic import BaseSettings
+
 from sundew.graph import Graph
-from sundew.types import FunctionTest
+from sundew.types import Cache
 
 
 class Configuration(BaseSettings):
     modules: set[str] = set()
-    function_graph: Graph = Graph()
-    tests: list[FunctionTest] = []
+    test_graph: Graph = Graph()
+    cache: Cache = Cache()
 
 
 config = Configuration()
